#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Copyright © Nekokatt 2019-2020
#
# This file is part of Hikari.
#
# Hikari is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Hikari is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Hikari. If not, see <https://www.gnu.org/licenses/>.

import argparse
import platform

import hikari

parser = argparse.ArgumentParser(prog=hikari.__name__, allow_abbrev=False)
parser.add_argument(
    "-V",
    "--version",
    action="version",
    version=f"{hikari.__name__} {hikari.__version__} from {hikari.__path__[0]} (python {platform.python_version()})",
    help=f"show {hikari.__name__}'s version and exit",
)
parser.set_defaults(func=parser.print_help)
parser.parse_args().func()
